@@ -13,6 +13,7 @@
 #include "abstractlogger.h"
 #include "copytool.h"
 #include "src/config/cacheutils.h"
+#include "src/config/generalconf.h"
 #include "src/core/flameshot.h"
 #include "src/core/qguiappcurrentscreen.h"
 #include "src/tools/toolfactory.h"
@@ -28,19 +29,23 @@
 #include "src/widgets/orientablepushbutton.h"
 #include "src/widgets/panel/sidepanelwidget.h"
 #include "src/widgets/panel/utilitypanel.h"
-#include "src/widgets/updatenotificationwidget.h"
 #include <QApplication>
+#include <QCheckBox>
 #include <QDateTime>
 #include <QDebug>
-#include <QDesktopWidget>
 #include <QFontMetrics>
 #include <QLabel>
+#include <QMessageBox>
 #include <QPaintEvent>
 #include <QPainter>
 #include <QScreen>
 #include <QShortcut>
 #include <draggablewidgetmaker.h>
 
+#if !defined(DISABLE_UPDATE_CHECKER)
+#include "src/widgets/updatenotificationwidget.h"
+#endif
+
 #define MOUSE_DISTANCE_TO_START_MOVING 3
 
 // CaptureWidget is the main component used to capture the screen. It contains
@@ -52,29 +57,32 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
                              bool fullScreen,
                              QWidget* parent)
   : QWidget(parent)
+  , m_toolSizeByKeyboard(0)
   , m_mouseIsClicked(false)
   , m_captureDone(false)
   , m_previewEnabled(true)
   , m_adjustmentButtonPressed(false)
   , m_configError(false)
   , m_configErrorResolved(false)
+#if !defined(DISABLE_UPDATE_CHECKER)
+  , m_updateNotificationWidget(nullptr)
+#endif
+  , m_lastMouseWheel(0)
   , m_activeButton(nullptr)
   , m_activeTool(nullptr)
-  , m_toolWidget(nullptr)
-  , m_colorPicker(nullptr)
-  , m_lastMouseWheel(0)
-  , m_updateNotificationWidget(nullptr)
   , m_activeToolIsMoved(false)
+  , m_toolWidget(nullptr)
   , m_panel(nullptr)
   , m_sidePanel(nullptr)
+  , m_colorPicker(nullptr)
   , m_selection(nullptr)
   , m_magnifier(nullptr)
+  , m_xywhDisplay(false)
   , m_existingObjectIsChanged(false)
   , m_startMove(false)
-  , m_toolSizeByKeyboard(0)
+
 {
     m_undoStack.setUndoLimit(ConfigHandler().undoLimit());
-
     m_context.circleCount = 1;
 
     // Base config of the widget
@@ -87,6 +95,9 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
             &HoverEventFilter::hoverOut,
             this,
             &CaptureWidget::childLeave);
+    connect(&m_xywhTimer, &QTimer::timeout, this, &CaptureWidget::xywhTick);
+    // else xywhTick keeps triggering when not needed
+    m_xywhTimer.setSingleShot(true);
     setAttribute(Qt::WA_DeleteOnClose);
     setAttribute(Qt::WA_QuitOnClose, false);
     m_opacity = m_config.contrastOpacity();
@@ -109,9 +120,12 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
         m_context.origScreenshot = m_context.screenshot;
 
 #if defined(Q_OS_WIN)
+// Call cmake with -DFLAMESHOT_DEBUG_CAPTURE=ON to enable easier debugging
+#if !defined(FLAMESHOT_DEBUG_CAPTURE)
         setWindowFlags(Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint |
                        Qt::SubWindow // Hides the taskbar icon
         );
+#endif
 
         for (QScreen* const screen : QGuiApplication::screens()) {
             QPoint topLeftScreen = screen->geometry().topLeft();
@@ -191,6 +205,13 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
 
     // Init color picker
     m_colorPicker = new ColorPicker(this);
+    // Init notification widget
+    m_notifierBox = new NotifierBox(this);
+    initPanel();
+
+    // TODO: Make it more clear why this has moved. In Qt6 some timing related
+    // to constructors / connect signals has changed so if initPanel is called
+    // after the connect a SEGFAULT occurs
     connect(m_colorPicker,
             &ColorPicker::colorSelected,
             this,
@@ -206,8 +227,6 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
             this,
             &CaptureWidget::onToolSizeChanged);
 
-    // Init notification widget
-    m_notifierBox = new NotifierBox(this);
     m_notifierBox->hide();
     connect(m_notifierBox, &NotifierBox::hidden, this, [this]() {
         // Show cursor if it was hidden while adjusting tool size
@@ -217,23 +236,24 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
         onToolSizeSettled(m_context.toolSize);
     });
 
-    initPanel();
-
     m_config.checkAndHandleError();
     if (m_config.hasError()) {
         m_configError = true;
     }
-    connect(ConfigHandler::getInstance(), &ConfigHandler::error, this, [=]() {
-        m_configError = true;
-        m_configErrorResolved = false;
-        OverlayMessage::instance()->update();
-    });
     connect(
-      ConfigHandler::getInstance(), &ConfigHandler::errorResolved, this, [=]() {
-          m_configError = false;
-          m_configErrorResolved = true;
+      ConfigHandler::getInstance(), &ConfigHandler::error, this, [=, this]() {
+          m_configError = true;
+          m_configErrorResolved = false;
           OverlayMessage::instance()->update();
       });
+    connect(ConfigHandler::getInstance(),
+            &ConfigHandler::errorResolved,
+            this,
+            [=, this]() {
+                m_configError = false;
+                m_configErrorResolved = true;
+                OverlayMessage::instance()->update();
+            });
 
     OverlayMessage::init(this,
                          QGuiAppCurrentScreen().currentScreen()->geometry());
@@ -243,6 +263,8 @@ CaptureWidget::CaptureWidget(const CaptureRequest& req,
         OverlayMessage::push(m_helpMessage);
     }
 
+    initQuitPrompt();
+
     updateCursor();
 }
 
@@ -284,7 +306,9 @@ void CaptureWidget::initButtons()
         for (auto* buttonList : { &allButtonTypes, &visibleButtonTypes }) {
             buttonList->removeOne(CaptureTool::TYPE_SAVE);
             buttonList->removeOne(CaptureTool::TYPE_COPY);
+#ifdef ENABLE_IMGUR
             buttonList->removeOne(CaptureTool::TYPE_IMAGEUPLOADER);
+#endif
             buttonList->removeOne(CaptureTool::TYPE_OPEN_APP);
             buttonList->removeOne(CaptureTool::TYPE_PIN);
         }
@@ -295,9 +319,6 @@ void CaptureWidget::initButtons()
     // This will allow keyboard shortcuts for those buttons to work
     for (CaptureTool::Type t : allButtonTypes) {
         auto* b = new CaptureToolButton(t, this);
-        if (t == CaptureTool::TYPE_SELECTIONINDICATOR) {
-            m_sizeIndButton = b;
-        }
         b->setColor(m_uiColor);
         b->hide();
         // must be enabled for SelectionWidget's eventFilter to work correctly
@@ -316,8 +337,8 @@ void CaptureWidget::initButtons()
                   ConfigHandler().shortcut(QVariant::fromValue(t).toString());
                 if (!shortcut.isNull()) {
                     auto shortcuts = newShortcut(shortcut, this, nullptr);
-                    for (auto* shortcut : shortcuts) {
-                        connect(shortcut, &QShortcut::activated, this, [=]() {
+                    for (auto* sc : shortcuts) {
+                        connect(sc, &QShortcut::activated, this, [=, this]() {
                             setState(b);
                         });
                     }
@@ -371,35 +392,60 @@ void CaptureWidget::handleButtonLeftClick(CaptureToolButton* b)
     if (!b) {
         return;
     }
-
     setState(b);
 }
 
+void CaptureWidget::xywhTick()
+{
+    m_xywhDisplay = false;
+    update();
+}
+
+void CaptureWidget::onDisplayGridChanged(bool display)
+{
+    m_displayGrid = display;
+    repaint();
+}
+
+void CaptureWidget::onGridSizeChanged(int size)
+{
+    m_gridSize = size;
+    repaint();
+}
+
+void CaptureWidget::showxywh()
+{
+    m_xywhDisplay = true;
+    update();
+    int timeout = m_config.showSelectionGeometryHideTime();
+    if (timeout != 0) {
+        m_xywhTimer.start(timeout);
+    }
+}
+
 void CaptureWidget::initHelpMessage()
 {
     QList<QPair<QString, QString>> keyMap;
-    if (keyMap.isEmpty()) {
-        keyMap << QPair(tr("Mouse"), tr("Select screenshot area"));
-        using CT = CaptureTool;
-        for (auto toolType :
-             { CT::TYPE_ACCEPT, CT::TYPE_SAVE, CT::TYPE_COPY }) {
-            if (!m_tools.contains(toolType)) {
-                continue;
-            }
-            auto* tool = m_tools[toolType];
-            QString shortcut = ConfigHandler().shortcut(
-              QVariant::fromValue(toolType).toString());
-            shortcut.replace("Return", "Enter");
-            if (!shortcut.isEmpty()) {
-                keyMap << QPair(shortcut, tool->description());
-            }
+    keyMap << std::pair(tr("Mouse"), tr("Select screenshot area"));
+    using CT = CaptureTool;
+    for (auto toolType : { CT::TYPE_ACCEPT, CT::TYPE_SAVE, CT::TYPE_COPY }) {
+        if (!m_tools.contains(toolType)) {
+            continue;
+        }
+        auto* tool = m_tools[toolType];
+        QString shortcut =
+          ConfigHandler().shortcut(QVariant::fromValue(toolType).toString());
+        shortcut.replace("Return", "Enter");
+        if (!shortcut.isEmpty()) {
+            keyMap << std::pair(shortcut, tool->description());
         }
-        keyMap << QPair(tr("Mouse Wheel"), tr("Change tool size"));
-        keyMap << QPair(tr("Right Click"), tr("Show color picker"));
-        keyMap << QPair(ConfigHandler().shortcut("TYPE_TOGGLE_PANEL"),
-                        tr("Open side panel"));
-        keyMap << QPair(tr("Esc"), tr("Exit"));
     }
+    keyMap << std::pair(tr("Mouse Wheel"), tr("Change tool size"));
+    keyMap << std::pair(tr("Right Click"), tr("Show color picker"));
+    keyMap << std::pair(ConfigHandler().shortcut("TYPE_TOGGLE_PANEL"),
+                        tr("Open side panel"));
+    keyMap << std::pair(tr("Esc"), tr("Exit"));
+
     m_helpMessage = OverlayMessage::compileFromKeyMap(keyMap);
 }
 
@@ -427,6 +473,46 @@ bool CaptureWidget::commitCurrentTool()
     return false;
 }
 
+void CaptureWidget::initQuitPrompt()
+{
+    m_quitPrompt = new QMessageBox;
+    makeChild(m_quitPrompt);
+
+    QString baseSheet = "QDialog { background-color: %1; }"
+                        "QLabel, QCheckBox { color: %2 }"
+                        "QPushButton { background-color: %1; color: %2 }";
+    QColor text = ColorUtils::colorIsDark(m_uiColor) ? Qt::white : Qt::black;
+    QString styleSheet = baseSheet.arg(m_uiColor.name(), text.name());
+
+    m_quitPrompt->setStyleSheet(styleSheet);
+    m_quitPrompt->setWindowTitle(tr("Quit Capture"));
+    m_quitPrompt->setText(tr("Are you sure you want to quit capture?"));
+    m_quitPrompt->setIcon(QMessageBox::Icon::Question);
+    m_quitPrompt->setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    m_quitPrompt->setDefaultButton(QMessageBox::No);
+
+    auto* check = new QCheckBox(tr("Do not show this again"));
+    m_quitPrompt->setCheckBox(check);
+
+    // Call show() first, otherwise the correct geometry cannot be fetched
+    // for centering the window on the screen
+    m_quitPrompt->show();
+    QRect position = m_quitPrompt->frameGeometry();
+    QScreen* currentScreen = QGuiAppCurrentScreen().currentScreen();
+    position.moveCenter(currentScreen->availableGeometry().center());
+    m_quitPrompt->move(position.topLeft());
+    m_quitPrompt->hide();
+
+    QObject::connect(check, &QCheckBox::clicked, [](bool checked) {
+        ConfigHandler().setShowQuitPrompt(!checked);
+    });
+}
+
+bool CaptureWidget::promptQuit()
+{
+    return m_quitPrompt->exec() == QMessageBox::Yes;
+}
+
 void CaptureWidget::deleteToolWidgetOrClose()
 {
     if (m_activeButton != nullptr) {
@@ -446,7 +532,14 @@ void CaptureWidget::deleteToolWidgetOrClose()
         m_colorPicker->hide();
     } else {
         // close CaptureWidget
-        close();
+        if (m_config.showQuitPrompt()) {
+            // need to show prompt
+            if (m_quitPrompt->isHidden() && promptQuit()) {
+                close();
+            }
+        } else {
+            close();
+        }
     }
 }
 
@@ -488,19 +581,117 @@ void CaptureWidget::paintEvent(QPaintEvent* paintEvent)
 {
     Q_UNUSED(paintEvent)
     QPainter painter(this);
+    GeneralConf::xywh_position position =
+      static_cast<GeneralConf::xywh_position>(m_config.showSelectionGeometry());
+    /* QPainter::save and restore is somewhat costly so we try to guess
+       if we need to do it here. What that means is that if you add
+       anything to the paintEvent and want to save/restore you should
+       add a test to the below if statement -- also if you change
+       any of the conditions that current trigger it you'll need to change here,
+       too
+    */
+    bool save = false;
+    if (m_xywhDisplay ||                           // clause 1: xywh display
+        m_displayGrid ||                           // clause 2: display grid
+        (m_activeTool && m_mouseIsClicked) ||      // clause 3: tool/click
+        (m_previewEnabled && activeButtonTool() && // clause 4: mouse preview
+         m_activeButton->tool()->showMousePreview())) {
+        painter.save();
+        save = true;
+    }
     painter.drawPixmap(0, 0, m_context.screenshot);
+    if (m_selection && m_xywhDisplay) {
+        const QRect& selection = m_selection->geometry().normalized();
+        const qreal scale = m_context.screenshot.devicePixelRatio();
+        QRect xybox;
+        QFontMetrics fm = painter.fontMetrics();
 
-    if (m_activeTool && m_mouseIsClicked) {
-        painter.save();
-        m_activeTool->process(painter, m_context.screenshot);
-        painter.restore();
-    } else if (m_previewEnabled && activeButtonTool() &&
-               m_activeButton->tool()->showMousePreview()) {
-        painter.save();
-        m_activeButton->tool()->paintMousePreview(painter, m_context);
-        painter.restore();
+        QString xy =
+          QString("%1x%2+%3+%4")
+            .arg(QString::number(static_cast<int>(selection.width() * scale)),
+                 QString::number(static_cast<int>(selection.height() * scale)),
+                 QString::number(static_cast<int>(selection.left() * scale)),
+                 QString::number(static_cast<int>(selection.top() * scale)));
+
+        xybox = fm.boundingRect(xy);
+        // the small numbers here are just margins so the text doesn't
+        // smack right up to the box; they aren't critical and the box
+        // size itself is tied to the font metrics
+        xybox.adjust(0, 0, 10, 12);
+        // in anticipation of making the position adjustable
+        int x0, y0;
+        // Move these to header
+
+        switch (position) {
+            case GeneralConf::xywh_top_left:
+                x0 = selection.left();
+                y0 = selection.top();
+                break;
+            case GeneralConf::xywh_bottom_left:
+                x0 = selection.left();
+                y0 = selection.bottom() - xybox.height();
+                break;
+            case GeneralConf::xywh_top_right:
+                x0 = selection.right() - xybox.width();
+                y0 = selection.top();
+                break;
+            case GeneralConf::xywh_bottom_right:
+                x0 = selection.right() - xybox.width();
+                y0 = selection.bottom() - xybox.height();
+                break;
+            case GeneralConf::xywh_center:
+            default:
+                x0 = selection.left() + (selection.width() - xybox.width()) / 2;
+                y0 =
+                  selection.top() + (selection.height() - xybox.height()) / 2;
+        }
+
+        QColor uicolor = ConfigHandler().uiColor();
+        uicolor.setAlpha(200);
+        painter.fillRect(
+          x0, y0, xybox.width(), xybox.height(), QBrush(uicolor));
+        painter.setPen(ColorUtils::colorIsDark(uicolor) ? Qt::white
+                                                        : Qt::black);
+        painter.drawText(x0,
+                         y0,
+                         xybox.width(),
+                         xybox.height(),
+                         Qt::AlignVCenter | Qt::AlignHCenter,
+                         xy);
     }
 
+    if (m_displayGrid) {
+        QColor uicolor = ConfigHandler().uiColor();
+        uicolor.setAlpha(100);
+        painter.setPen(uicolor);
+        painter.setBrush(QBrush(uicolor));
+
+        const auto scale{ m_context.screenshot.devicePixelRatio() };
+        auto topLeft = mapToGlobal(m_context.selection.topLeft() / scale);
+        topLeft.rx() -= topLeft.x() % m_gridSize;
+        topLeft.ry() -= topLeft.y() % m_gridSize;
+        topLeft = mapFromGlobal(topLeft);
+
+        const auto step{ m_gridSize / scale };
+        const auto radius{ 1 * scale };
+
+        for (int y = topLeft.y(); y < m_context.selection.bottom() / scale;
+             y += step) {
+            for (int x = topLeft.x(); x < m_context.selection.right() / scale;
+                 x += step) {
+                painter.drawEllipse(x, y, radius, radius);
+            }
+        }
+    }
+
+    if (m_activeTool && m_mouseIsClicked) {
+        m_activeTool->process(painter, m_context.screenshot);
+    } else if (m_previewEnabled && activeButtonTool() &&
+               m_activeButton->tool()->showMousePreview()) {
+        m_activeButton->tool()->paintMousePreview(painter, m_context);
+    }
+    if (save)
+        painter.restore();
     // draw inactive region
     drawInactiveRegion(&painter);
 
@@ -559,7 +750,8 @@ bool CaptureWidget::startDrawObjectTool(const QPoint& pos)
                 &CaptureTool::requestAction,
                 this,
                 &CaptureWidget::handleToolSignal);
-        m_context.mousePos = pos;
+
+        m_context.mousePos = m_displayGrid ? snapToGrid(pos) : pos;
         m_activeTool->drawStart(m_context);
         // TODO this is the wrong place to do this
 
@@ -614,12 +806,10 @@ void CaptureWidget::mousePressEvent(QMouseEvent* e)
         updateCursor();
         return;
     }
-
     // reset object selection if capture area selection is active
     if (m_selection->getMouseSide(e->pos()) != SelectionWidget::CENTER) {
         m_panel->setActiveLayer(-1);
     }
-
     if (e->button() == Qt::RightButton) {
         if (m_activeTool && m_activeTool->editMode()) {
             return;
@@ -646,7 +836,6 @@ void CaptureWidget::mousePressEvent(QMouseEvent* e)
     }
 
     selectToolItemAtPos(m_mousePressedPos);
-
     updateSelectionState();
     updateCursor();
 }
@@ -737,7 +926,8 @@ void CaptureWidget::mouseMoveEvent(QMouseEvent* e)
         if (m_adjustmentButtonPressed) {
             m_activeTool->drawMoveWithAdjustment(e->pos());
         } else {
-            m_activeTool->drawMove(e->pos());
+            m_activeTool->drawMove(m_displayGrid ? snapToGrid(e->pos())
+                                                 : e->pos());
         }
         // update drawing object
         updateTool(m_activeTool);
@@ -1016,6 +1206,14 @@ void CaptureWidget::initPanel()
             &SidePanelWidget::togglePanel,
             m_panel,
             &UtilityPanel::toggle);
+    connect(m_sidePanel,
+            &SidePanelWidget::displayGridChanged,
+            this,
+            &CaptureWidget::onDisplayGridChanged);
+    connect(m_sidePanel,
+            &SidePanelWidget::gridSizeChanged,
+            this,
+            &CaptureWidget::onGridSizeChanged);
     // TODO replace with a CaptureWidget signal
     emit m_sidePanel->colorChanged(m_context.color);
     emit toolSizeChanged(m_context.toolSize);
@@ -1025,6 +1223,7 @@ void CaptureWidget::initPanel()
     m_panel->fillCaptureTools(m_captureToolObjects.captureToolObjects());
 }
 
+#if !defined(DISABLE_UPDATE_CHECKER)
 void CaptureWidget::showAppUpdateNotification(const QString& appLatestVersion,
                                               const QString& appLatestUrl)
 {
@@ -1038,10 +1237,6 @@ void CaptureWidget::showAppUpdateNotification(const QString& appLatestVersion,
     }
 #if defined(Q_OS_MACOS)
     int ax = (width() - m_updateNotificationWidget->width()) / 2;
-#elif (defined(Q_OS_LINUX) && QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    QRect helpRect = QGuiApplication::primaryScreen()->geometry();
-    int ax = helpRect.left() +
-             ((helpRect.width() - m_updateNotificationWidget->width()) / 2);
 #else
     QRect helpRect;
     QScreen* currentScreen = QGuiAppCurrentScreen().currentScreen();
@@ -1057,6 +1252,7 @@ void CaptureWidget::showAppUpdateNotification(const QString& appLatestVersion,
     makeChild(m_updateNotificationWidget);
     m_updateNotificationWidget->show();
 }
+#endif
 
 void CaptureWidget::initSelection()
 {
@@ -1067,9 +1263,10 @@ void CaptureWidget::initSelection()
         QRect constrainedToCaptureArea =
           m_selection->geometry().intersected(rect());
         m_context.selection = extendedRect(constrainedToCaptureArea);
-        updateSizeIndicator();
+
         m_buttonHandler->hide();
         updateCursor();
+        updateSizeIndicator();
         OverlayMessage::pop();
     });
     connect(m_selection, &SelectionWidget::geometrySettled, this, [this]() {
@@ -1092,8 +1289,13 @@ void CaptureWidget::initSelection()
         }
     });
     if (!initialSelection.isNull()) {
+        const qreal scale = m_context.screenshot.devicePixelRatio();
         initialSelection.moveTopLeft(initialSelection.topLeft() -
-                                     mapToGlobal({}));
+                                     mapToGlobal(QPoint(0, 0)));
+        initialSelection.setTop(initialSelection.top() / scale);
+        initialSelection.setBottom(initialSelection.bottom() / scale);
+        initialSelection.setLeft(initialSelection.left() / scale);
+        initialSelection.setRight(initialSelection.right() / scale);
     }
     m_selection->setGeometry(initialSelection);
     m_selection->setVisible(!initialSelection.isNull());
@@ -1200,6 +1402,7 @@ void CaptureWidget::handleToolSignal(CaptureTool::Request r)
                 w->setAttribute(Qt::WA_DeleteOnClose);
                 w->activateWindow();
                 w->show();
+                Flameshot::instance()->setExternalWidget(true);
             }
             break;
         case CaptureTool::REQ_INCREASE_TOOL_SIZE:
@@ -1332,15 +1535,13 @@ void CaptureWidget::removeToolObject(int index)
     --index;
     if (index >= 0 && index < m_captureToolObjects.size()) {
         // in case this tool is circle counter
-        int removedCircleCount = -1;
-
         const CaptureTool::Type currentToolType =
           m_captureToolObjects.at(index)->type();
         m_captureToolObjectsBackup = m_captureToolObjects;
         update(
           paddedUpdateRect(m_captureToolObjects.at(index)->boundingRect()));
         if (currentToolType == CaptureTool::TYPE_CIRCLECOUNT) {
-            removedCircleCount = m_captureToolObjects.at(index)->count();
+            int removedCircleCount = m_captureToolObjects.at(index)->count();
             --m_context.circleCount;
             // Decrement circle counter numbers starting from deleted circle
             for (int cnt = 0; cnt < m_captureToolObjects.size(); cnt++) {
@@ -1385,6 +1586,18 @@ void CaptureWidget::initShortcuts()
     newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_RESIZE_DOWN")),
                 m_selection,
                 SLOT(resizeDown()));
+    newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_SYM_RESIZE_LEFT")),
+                m_selection,
+                SLOT(symResizeLeft()));
+    newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_SYM_RESIZE_RIGHT")),
+                m_selection,
+                SLOT(symResizeRight()));
+    newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_SYM_RESIZE_UP")),
+                m_selection,
+                SLOT(symResizeUp()));
+    newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_SYM_RESIZE_DOWN")),
+                m_selection,
+                SLOT(symResizeDown()));
 
     newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_MOVE_LEFT")),
                 m_selection,
@@ -1399,6 +1612,10 @@ void CaptureWidget::initShortcuts()
                 m_selection,
                 SLOT(moveDown()));
 
+    newShortcut(QKeySequence(ConfigHandler().shortcut("TYPE_CANCEL")),
+                this,
+                SLOT(cancel()));
+
     newShortcut(
       QKeySequence(ConfigHandler().shortcut("TYPE_DELETE_CURRENT_TOOL")),
       this,
@@ -1428,11 +1645,13 @@ void CaptureWidget::deleteCurrentTool()
 
 void CaptureWidget::updateSizeIndicator()
 {
+    if (m_config.showSelectionGeometry()) {
+        showxywh();
+    }
     if (m_sizeIndButton) {
         const QRect& selection = extendedSelection();
-        m_sizeIndButton->setText(QStringLiteral("%1\n%2")
-                                   .arg(selection.width())
-                                   .arg(selection.height()));
+        m_sizeIndButton->setText(
+          QStringLiteral("%1\n%2").arg(selection.width(), selection.height()));
     }
 }
 
@@ -1537,7 +1756,7 @@ void CaptureWidget::drawToolsData(bool drawSelection)
     // TODO refactor this for performance. The objects should not all be updated
     // at once every time
     QPixmap pixmapItem = m_context.origScreenshot;
-    for (auto toolItem : m_captureToolObjects.captureToolObjects()) {
+    for (const auto& toolItem : m_captureToolObjects.captureToolObjects()) {
         processPixmapWithTool(&pixmapItem, toolItem);
         update(paddedUpdateRect(toolItem->boundingRect()));
     }
@@ -1588,6 +1807,18 @@ CaptureTool::Type CaptureWidget::activeButtonToolType() const
     return activeTool->type();
 }
 
+QPoint CaptureWidget::snapToGrid(const QPoint& point) const
+{
+    QPoint snapPoint = mapToGlobal(point);
+
+    const auto scale{ m_context.screenshot.devicePixelRatio() };
+
+    snapPoint.setX((qRound(snapPoint.x() / double(m_gridSize)) * m_gridSize));
+    snapPoint.setY((qRound(snapPoint.y() / double(m_gridSize)) * m_gridSize));
+
+    return mapFromGlobal(snapPoint);
+}
+
 QPointer<CaptureTool> CaptureWidget::activeToolObject()
 {
     return m_captureToolObjects.at(m_panel->activeLayerIndex());
@@ -1693,6 +1924,23 @@ void CaptureWidget::redo()
     restoreCircleCountState();
 }
 
+void CaptureWidget::cancel()
+{
+    if (m_activeButton != nullptr) {
+        uncheckActiveTool();
+    }
+    if (m_panel) {
+        m_panel->setActiveLayer(-1);
+    }
+    if (m_toolWidget) {
+        m_toolWidget->hide();
+        delete m_toolWidget;
+        m_toolWidget = nullptr;
+    }
+    m_selection->hide();
+    emit m_selection->geometrySettled();
+}
+
 QRect CaptureWidget::extendedSelection() const
 {
     if (m_selection == nullptr) {
